==> ldapsaisie_1.7-2.tar.gz: ldapsaisie_clean/public_html/tmp/0c0cdc624b313c865b2310deb02d1114cb5530fb_0.ls.login.tpl.php <==
<?php
/* Smarty version 3.1.31, created on 2017-07-08 16:39:59
  from "ls:login.tpl" */

/* @var Smarty_Internal_Template $_smarty_tpl */
if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
  'version' => '3.1.31',
  'unifunc' => 'content_59610adfd59111_74460621',
  'has_nocache_code' => false,
  'file_dependency' => 
  array (
    '0c0cdc624b313c865b2310deb02d1114cb5530fb' => 
    array (
      0 => 'ls:login.tpl',
      1 => 1485860881,
      2 => 'ls',
    ),
  ),
  'includes' => 
  array (
    'ls:LSdefault.tpl' => 1,
  ),
),false)) {
function content_59610adfd59111_74460621 (Smarty_Internal_Template $_smarty_tpl) {
if (!is_callable('smarty_function_html_options')) require_once '/usr/share/php/smarty3/plugins/function.html_options.php';
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
 "http://www.w3.org/TR/html4/loose.dtd">
<html>
  <head>
    <meta http-equiv="content-type" content="text/html; charset=UTF-8">
    <title>LdapSaisie<?php if ($_smarty_tpl->tpl_vars['pagetitle']->value != '') {?> - <?php echo $_smarty_tpl->tpl_vars['pagetitle']->value;
}?></title>
    <link rel="icon" type="image/png" href="images/default/favicon.png" />
    <link rel="stylesheet" type="text/css" href="<?php echo LStemplate_smarty_css(array('name'=>'login.css'),$_smarty_tpl);?>
" media="screen" title="Normal" />
    <?php echo $_smarty_tpl->tpl_vars['LSsession_css']->value;?>

    <?php echo $_smarty_tpl->tpl_vars['LSsession_js']->value;?>

  </head>
<body>

<?php $_smarty_tpl->_subTemplateRender('ls:LSdefault.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, $_smarty_tpl->cache_lifetime, array(), 0, false);
?>


<div class='loginform'>
<img src='<?php echo LStemplate_smarty_img(array('name'=>'logo'),$_smarty_tpl);?>
' alt='Logo' id='loginform_logo' />
<div id='loading_zone'></div>
<form action='<?php echo $_smarty_tpl->tpl_vars['loginform_action']->value;?>
' method='post'>
<dl class='loginform'>
  <dt <?php echo $_smarty_tpl->tpl_vars['loginform_ldapserver_style']->value;?>
><?php echo $_smarty_tpl->tpl_vars['loginform_label_ldapserver']->value;?>
</dt>
  <dd <?php echo $_smarty_tpl->tpl_vars['loginform_ldapserver_style']->value;?>
>
    <select name='LSsession_ldapserver' id='LSsession_ldapserver'><?php echo smarty_function_html_options(array('values'=>$_smarty_tpl->tpl_vars['loginform_ldapservers_index']->value,'output'=>$_smarty_tpl->tpl_vars['loginform_ldapservers_name']->value,'selected'=>$_smarty_tpl->tpl_vars['ldapServerId']->value),$_smarty_tpl);?>
</select>
  </dd>
  <dt class='loginform-level' id='LSsession_topDn_label' <?php echo $_smarty_tpl->tpl_vars['loginform_ldapserver_style']->value;?>
><?php echo $_smarty_tpl->tpl_vars['loginform_label_level']->value;?>
</dt>
  <dd class='loginform-level' <?php echo $_smarty_tpl->tpl_vars['loginform_ldapserver_style']->value;?>
><select name='LSsession_topDn' id='LSsession_topDn'><?php echo smarty_function_html_options(array('values'=>$_smarty_tpl->tpl_vars['loginform_topdn_index']->value,'output'=>$_smarty_tpl->tpl_vars['loginform_topdn_name']->value,'selected'=>$_smarty_tpl->tpl_vars['topDn']->value),$_smarty_tpl);?>
</select></dd>
  <dt><?php echo $_smarty_tpl->tpl_vars['loginform_label_user']->value;?>
</dt>
  <dd><input type='text' name='LSauth_user' /></dd>
  <dt><?php echo $_smarty_tpl->tpl_vars['loginform_label_pwd']->value;?>
</dt>
  <dd><input type='password' name='LSauth_pwd' /></dd>
  <dt class='LSlang_hidden'><?php echo $_smarty_tpl->tpl_vars['lang_label']->value;?>
</dt>
  <dd class='LSlang_hidden'>
  <select name='lang'>
  <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSlanguages']->value, 'lang');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['lang']->value) {
?>
    <option value='<?php echo $_smarty_tpl->tpl_vars['lang']->value;?>
'><?php echo $_smarty_tpl->tpl_vars['lang']->value;?>
</option>
  <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

  </select>
  </dd>
  <dd><input type='submit' value='<?php echo $_smarty_tpl->tpl_vars['loginform_label_submit']->value;?>
' /></dd>
</dl>
</form>
<span><?php echo $_smarty_tpl->tpl_vars['lang_label']->value;?>
 : <img id='LSlang' src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['LSlang']->value),$_smarty_tpl);?>
' alt='<?php echo $_smarty_tpl->tpl_vars['LSlang']->value;?>
' title='<?php echo $_smarty_tpl->tpl_vars['LSlang']->value;?>
'/></span>
<a href='index.php?LSsession_recoverPassword' class='LSsession_recoverPassword LSsession_recoverPassword_hidden'><?php echo $_smarty_tpl->tpl_vars['loginform_label_recoverPassword']->value;?>
</a>
</div>
</body>
</html>
<?php }
}

==> ldapsaisie_1.8-1.tar.gz: ldapsaisie_clean/public_html/tmp/0c0cdc624b313c865b2310deb02d1114cb5530fb_0.ls.login.tpl.php <==
<?php
/* Smarty version {Smarty::SMARTY_VERSION}, created on 2018-04-27 07:59:51
  from "ls:login.tpl" */

/* @var Smarty_Internal_Template $_smarty_tpl */
if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
  'version' => '3.1.31',
  'unifunc' => 'content_5ae2d8772746f4_64479219',
  'has_nocache_code' => false,
  'file_dependency' => 
  array (
    '0c0cdc624b313c865b2310deb02d1114cb5530fb' => 
    array (
      0 => 'ls:login.tpl',
      1 => 1472212472,
      2 => 'ls',
    ),
  ),
  'includes' => 
  array (
    'ls:LSdefault.tpl' => 1,
  ),
),false)) {
function content_5ae2d8772746f4_64479219 (Smarty_Internal_Template $_smarty_tpl) {
if (!is_callable('smarty_function_html_options')) require_once '/usr/share/php/smarty3/plugins/function.html_options.php';
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
 "http://www.w3.org/TR/html4/loose.dtd">
<html>
  <head>
    <meta http-equiv="content-type" content="text/html; charset=UTF-8">
    <title>LdapSaisie<?php if ($_smarty_tpl->tpl_vars['pagetitle']->value != '') {?> - <?php echo $_smarty_tpl->tpl_vars['pagetitle']->value;
}?></title>
    <link rel="icon" type="image/png" href="images/default/favicon.png" />
    <link rel="stylesheet" type="text/css" href="<?php echo LStemplate_smarty_css(array('name'=>'login.css'),$_smarty_tpl);?>
" media="screen" title="Normal" />
    <?php echo $_smarty_tpl->tpl_vars['LSsession_css']->value;?>

    <?php echo $_smarty_tpl->tpl_vars['LSsession_js']->value;?>

  </head>
<body>

<?php $_smarty_tpl->_subTemplateRender('ls:LSdefault.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, $_smarty_tpl->cache_lifetime, array(), 0, false);
?>


<div class='loginform'>
<img src='<?php echo LStemplate_smarty_img(array('name'=>'logo'),$_smarty_tpl);?>
' alt='Logo' id='loginform_logo' />
<div id='loading_zone'></div>
<form action='<?php echo $_smarty_tpl->tpl_vars['loginform_action']->value;?>
' method='post'>
<dl class='loginform'>
  <dt <?php echo $_smarty_tpl->tpl_vars['loginform_ldapserver_style']->value;?>
><?php echo $_smarty_tpl->tpl_vars['loginform_label_ldapserver']->value;?>
</dt>
  <dd <?php echo $_smarty_tpl->tpl_vars['loginform_ldapserver_style']->value;?>
>
    <select name='LSsession_ldapserver' id='LSsession_ldapserver'><?php echo smarty_function_html_options(array('values'=>$_smarty_tpl->tpl_vars['loginform_ldapservers_index']->value,'output'=>$_smarty_tpl->tpl_vars['loginform_ldapservers_name']->value,'selected'=>$_smarty_tpl->tpl_vars['ldapServerId']->value),$_smarty_tpl);?>
</select>
  </dd>
  <dt class='loginform-level' id='LSsession_topDn_label' <?php echo $_smarty_tpl->tpl_vars['loginform_ldapserver_style']->value;?>
><?php echo $_smarty_tpl->tpl_vars['loginform_label_level']->value;?>
</dt>
  <dd class='loginform-level' <?php echo $_smarty_tpl->tpl_vars['loginform_ldapserver_style']->value;?>
><select name='LSsession_topDn' id='LSsession_topDn'><?php echo smarty_function_html_options(array('values'=>$_smarty_tpl->tpl_vars['loginform_topdn_index']->value,'output'=>$_smarty_tpl->tpl_vars['loginform_topdn_name']->value,'selected'=>$_smarty_tpl->tpl_vars['topDn']->value),$_smarty_tpl);?>
</select></dd>
  <dt><?php echo $_smarty_tpl->tpl_vars['loginform_label_user']->value;?>
</dt>
  <dd><input type='text' name='LSauth_user' /></dd>
  <dt><?php echo $_smarty_tpl->tpl_vars['loginform_label_pwd']->value;?>
</dt>
  <dd><input type='password' name='LSauth_pwd' /></dd>
  <dt class='LSlang_hidden'><?php echo $_smarty_tpl->tpl_vars['lang_label']->value;?>
</dt>
  <dd class='LSlang_hidden'>
  <select name='lang'>
  <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSlanguages']->value, 'lang');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['lang']->value) {
?>
    <option value='<?php echo $_smarty_tpl->tpl_vars['lang']->value;?>
'><?php echo $_smarty_tpl->tpl_vars['lang']->value;?>
</option>
  <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

  </select>
  </dd>
  <dd><input type='submit' value='<?php echo $_smarty_tpl->tpl_vars['loginform_label_submit']->value;?>
' /></dd>
</dl>
</form>
<span><?php echo $_smarty_tpl->tpl_vars['lang_label']->value;?>
 : <img id='LSlang' src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['LSlang']->value),$_smarty_tpl);?>
' alt='<?php echo $_smarty_tpl->tpl_vars['LSlang']->value;?>
' title='<?php echo $_smarty_tpl->tpl_vars['LSlang']->value;?>
'/></span>
<a href='index.php?LSsession_recoverPassword' class='LSsession_recoverPassword LSsession_recoverPassword_hidden'><?php echo $_smarty_tpl->tpl_vars['loginform_label_recoverPassword']->value;?>
</a>
</div>
</body>
</html>
<?php }
}
